darkhistory.physics.YHe — DarkHistory documentation

- Repository
- DarkHistory documentation
- DarkHistory
- darkhistory
- darkhistory.physics

- index
- modules
- next
- previous

# darkhistory.physics.YHe

`darkhistory.physics.` `YHe` = 0.24

  Helium abundance by mass.

#### Previous topic

darkhistory.physics.chi

#### Next topic

darkhistory.physics.hubble

### This Page

Show Source

- © Copyright 2019, Hongwan Liu, Gregory Ridgway and Tracy Slatyer.
- Created using Sphinx 1.8.5.